==> gat-0.25.2.tar.gz: gat-0.25.2/docs/languages.md <==
# Languages

| Language | Aliases |
| --- | --- |
| `ABAP` | `abap` |
| `ABNF` | `abnf` |
| `ActionScript` | `as`, `actionscript` |
| `ActionScript 3` | `as3`, `actionscript3` |
| `Ada` | `ada`, `ada95`, `ada2005` |
| `Agda` | `agda` |
| `AL` | `al` |
| `Alloy` | `alloy` |
| `Angular2` | `ng2` |
| `ANTLR` | `antlr` |
| `ApacheConf` | `apacheconf`, `aconf`, `apache` |
| `APL` | `apl` |
| `AppleScript` | `applescript` |
| `ArangoDB AQL` | `aql` |
| `Arduino` | `arduino` |
| `ArmAsm` | `armasm` |
| `ATL` | `atl` |
| `AutoHotkey` | `autohotkey`, `ahk` |
| `AutoIt` | `autoit` |
| `Awk` | `awk`, `gawk`, `mawk`, `nawk` |
| `Ballerina` | `ballerina` |
| `Bash` | `bash`, `sh`, `ksh`, `zsh`, `shell` |
| `Bash Session` | `bash-session`, `console`, `shell-session` |
| `Batchfile` | `bat`, `batch`, `dosbatch`, `winbatch` |
| `Beef` | `beef` |
| `BibTeX` | `bib`, `bibtex` |
| `Bicep` | `bicep` |
| `BlitzBasic` | `blitzbasic`, `b3d`, `bplus` |
| `BNF` | `bnf` |
| `BQN` | `bqn` |
| `Brainfuck` | `brainfuck`, `bf` |
| `C#` | `csharp`, `c#` |
| `C++` | `cpp`, `c++` |
| `C` | `c` |
| `Cap'n Proto` | `capnp` |
| `Cassandra CQL` | `cassandra`, `cql` |
| `Ceylon` | `ceylon` |
| `CFEngine3` | `cfengine3`, `cf3` |
| `cfstatement` | `cfs` |
| `ChaiScript` | `chai`, `chaiscript` |
| `Chapel` | `chapel`, `chpl` |
| `Cheetah` | `cheetah`, `spitfire` |
| `Clojure` | `clojure`, `clj`, `edn` |
| `CMake` | `cmake` |
| `COBOL` | `cobol` |
| `CoffeeScript` | `coffee-script`, `coffeescript`, `coffee` |
| `Common Lisp` | `common-lisp`, `cl`, `lisp` |
| `Coq` | `coq` |
| `Core` | `core` |
| `Crystal` | `cr`, `crystal` |
| `CSS` | `css` |
| `CSV` | `csv` |
| `CUE` | `cue` |
| `Cython` | `cython`, `pyx`, `pyrex` |
| `D` | `d` |
| `Dart` | `dart` |
| `Dax` | `dax` |
| `Desktop file` | `desktop`, `desktop_entry` |
| `Diff` | `diff`, `udiff` |
| `Django/Jinja` | `django`, `jinja` |
| `dns` | `zone`, `bind` |
| `Docker` | `docker`, `dockerfile`, `containerfile` |
| `DTD` | `dtd` |
| `Dylan` | `dylan` |
| `EBNF` | `ebnf` |
| `Elixir` | `elixir`, `ex`, `exs` |
| `Elm` | `elm` |
| `EmacsLisp` | `emacs`, `elisp`, `emacs-lisp` |
| `Erlang` | `erlang` |
| `Factor` | `factor` |
| `Fennel` | `fennel`, `fnl` |
| `Fish` | `fish`, `fishshell` |
| `Forth` | `forth` |
| `Fortran` | `fortran`, `f90` |
| `FortranFixed` | `fortranfixed` |
| `FSharp` | `fsharp` |
| `GAS` | `gas`, `asm` |
| `GDScript` | `gdscript`, `gd` |
| `GDScript3` | `gdscript3`, `gd3` |
| `Gherkin` | `cucumber`, `Cucumber`, `gherkin`, `Gherkin` |
| `Gleam` | `gleam` |
| `GLSL` | `glsl` |
| `Gnuplot` | `gnuplot` |
| `Go Template` | `go-template` |
| `GraphQL` | `graphql`, `graphqls`, `gql` |
| `Groff` | `groff`, `nroff`, `man` |
| `Groovy` | `groovy` |
| `Handlebars` | `handlebars`, `hbs` |
| `Hare` | `hare` |
| `Haskell` | `haskell`, `hs` |
| `HCL` | `hcl` |
| `Hexdump` | `hexdump` |
| `HLB` | `hlb` |
| `HLSL` | `hlsl` |
| `HolyC` | `holyc` |
| `HTML` | `html` |
| `Hy` | `hylang` |
| `Idris` | `idris`, `idr` |
| `Igor` | `igor`, `igorpro` |
| `INI` | `ini`, `cfg`, `dosini` |
| `Io` | `io` |
| `ISCdhcpd` | `iscdhcpd` |
| `J` | `j` |
| `Janet` | `janet` |
| `Java` | `java` |
| `JavaScript` | `js`, `javascript` |
| `JSON` | `json` |
| `JSONata` | `jsonata` |
| `Jsonnet` | `jsonnet` |
| `Julia` | `julia`, `jl` |
| `Jungle` | `jungle` |
| `Kotlin` | `kotlin` |
| `Lean4` | `lean4`, `lean` |
| `Lighttpd configuration file` | `lighty`, `lighttpd` |
| `LLVM` | `llvm` |
| `lox` | |
| `Lua` | `lua`, `luau` |
| `Makefile` | `make`, `makefile`, `mf`, `bsdmake` |
| `Mako` | `mako` |
| `Mason` | `mason` |
| `Materialize SQL dialect` | `materialize`, `mzsql` |
| `Mathematica` | `mathematica`, `mma`, `nb` |
| `Matlab` | `matlab` |
| `MCFunction` | `mcfunction`, `mcf` |
| `Meson` | `meson`, `meson.build` |
| `Metal` | `metal` |
| `MiniZinc` | `minizinc`, `MZN`, `mzn` |
| `MLIR` | `mlir` |
| `Modula-2` | `modula2`, `m2` |
| `Mojo` | `mojo`, `🔥` |
| `MonkeyC` | `monkeyc` |
| `MoonScript` | `moonscript`, `moon` |
| `MorrowindScript` | `morrowind`, `mwscript` |
| `Myghty` | `myghty` |
| `MySQL` | `mysql`, `mariadb` |
| `NASM` | `nasm` |
| `Natural` | `natural` |
| `NDISASM` | `ndisasm` |
| `Newspeak` | `newspeak` |
| `Nginx configuration file` | `nginx` |
| `Nim` | `nim`, `nimrod` |
| `Nix` | `nixos`, `nix` |
| `NSIS` | `nsis`, `nsi`, `nsh` |
| `Nu` | `nu` |
| `Objective-C` | `objective-c`, `objectivec`, `obj-c`, `objc` |
| `ObjectPascal` | `objectpascal` |
| `OCaml` | `ocaml` |
| `Octave` | `octave` |
| `Odin` | `odin` |
| `OnesEnterprise` | `ones`, `onesenterprise`, `1S`, `1S:Enterprise` |
| `OpenEdge ABL` | `openedge`, `abl`, `progress`, `openedgeabl` |
| `OpenSCAD` | `openscad` |
| `Org Mode` | `org`, `orgmode` |
| `PacmanConf` | `pacmanconf` |
| `Perl` | `perl`, `pl` |
| `PHP` | `php`, `php3`, `php4`, `php5` |
| `Pig` | `pig` |
| `PkgConfig` | `pkgconfig` |
| `PL/pgSQL` | `plpgsql` |
| `plaintext` | `text`, `plain`, `no-highlight` |
| `Plutus Core` | `plutus-core`, `plc` |
| `Pony` | `pony` |
| `PostgreSQL SQL dialect` | `postgresql`, `postgres` |
| `PostScript` | `postscript`, `postscr` |
| `POVRay` | `pov` |
| `PowerQuery` | `powerquery`, `pq` |
| `PowerShell` | `powershell`, `posh`, `ps1`, `psm1`, `psd1`, `pwsh` |
| `Prolog` | `prolog` |
| `Promela` | `promela` |
| `PromQL` | `promql` |
| `properties` | `java-properties` |
| `Protocol Buffer` | `protobuf`, `proto` |
| `PRQL` | `prql` |
| `PSL` | `psl` |
| `Puppet` | `puppet` |
| `Python` | `python`, `py`, `sage`, `python3`, `py3` |
| `Python 2` | `python2`, `py2` |
| `QBasic` | `qbasic`, `basic` |
| `QML` | `qml`, `qbs` |
| `R` | `splus`, `s`, `r` |
| `Racket` | `racket`, `rkt` |
| `Ragel` | `ragel` |
| `react` | `jsx`, `react` |
| `ReasonML` | `reason`, `reasonml` |
| `reg` | `registry` |
| `Rego` | `rego` |
| `Rexx` | `rexx`, `arexx` |
| `RPGLE` | `SQLRPGLE`, `RPG IV` |
| `RPMSpec` | `spec` |
| `Ruby` | `rb`, `ruby`, `duby` |
| `Rust` | `rust`, `rs` |
| `SAS` | `sas` |
| `Sass` | `sass` |
| `Scala` | `scala` |
| `Scheme` | `scheme`, `scm` |
| `Scilab` | `scilab` |
| `SCSS` | `scss` |
| `Sed` | `sed`, `gsed`, `ssed` |
| `Sieve` | `sieve` |
| `Smali` | `smali` |
| `Smalltalk` | `smalltalk`, `squeak`, `st` |
| `Smarty` | `smarty` |
| `SNBT` | `snbt` |
| `Snobol` | `snobol` |
| `Solidity` | `sol`, `solidity` |
| `SourcePawn` | `sp` |
| `SPARQL` | `sparql` |
| `SQL` | `sql` |
| `SquidConf` | `squidconf`, `squid.conf`, `squid` |
| `Standard ML` | `sml` |
| `stas` | |
| `Stylus` | `stylus` |
| `Swift` | `swift` |
| `SYSTEMD` | `systemd` |
| `systemverilog` | `systemverilog`, `sv` |
| `TableGen` | `tablegen` |
| `Tal` | `tal`, `uxntal` |
| `TASM` | `tasm` |
| `Tcl` | `tcl` |
| `Tcsh` | `tcsh`, `csh` |
| `Termcap` | `termcap` |
| `Terminfo` | `terminfo` |
| `Terraform` | `terraform`, `tf`, `hcl` |
| `TeX` | `tex`, `latex` |
| `Thrift` | `thrift` |
| `TOML` | `toml` |
| `TradingView` | `tradingview`, `tv` |
| `Transact-SQL` | `tsql`, `t-sql` |
| `Turing` | `turing` |
| `Turtle` | `turtle` |
| `Twig` | `twig` |
| `TypeScript` | `ts`, `tsx`, `typescript` |
| `TypoScript` | `typoscript` |
| `TypoScriptCssData` | `typoscriptcssdata` |
| `TypoScriptHtmlData` | `typoscripthtmldata` |
| `Typst` | `typst` |
| `ucode` | |
| `V` | `v`, `vlang` |
| `V shell` | `vsh`, `vshell` |
| `Vala` | `vala`, `vapi` |
| `VB.net` | `vb.net`, `vbnet` |
| `verilog` | `verilog`, `v` |
| `VHDL` | `vhdl` |
| `VHS` | `vhs`, `tape`, `cassette` |
| `VimL` | `vim` |
| `vue` | `vue`, `vuejs` |
| `WDTE` | |
| `WebGPU Shading Language` | `wgsl` |
| `WebVTT` | `vtt` |
| `Whiley` | `whiley` |
| `XML` | `xml` |
| `Xorg` | `xorg.conf` |
| `YAML` | `yaml` |
| `YANG` | `yang` |
| `Z80 Assembly` | `z80` |
| `Zed` | `zed` |
| `Zig` | `zig` |
| `Caddyfile` | `caddyfile`, `caddy` |
| `Caddyfile Directives` | `caddyfile-directives`, `caddyfile-d`, `caddy-d` |
| `Gemtext` | `gemtext`, `gmi`, `gmni`, `gemini` |
| `Genshi Text` | `genshitext` |
| `Genshi HTML` | `html+genshi`, `html+kid` |
| `Genshi` | `genshi`, `kid`, `xml+genshi`, `xml+kid` |
| `Go HTML Template` | `go-html-template` |
| `Go Text Template` | `go-text-template` |
| `Go` | `go`, `golang` |
| `Haxe` | `hx`, `haxe`, `hxsl` |
| `HTTP` | `http` |
| `markdown` | `md`, `mkd` |
| `PHTML` | `phtml` |
| `Raku` | `perl6`, `pl6`, `raku` |
| `reStructuredText` | `rst`, `rest`, `restructuredtext` |
| `Svelte` | `svelte` |

==> gat-0.26.1.tar.gz: gat-0.26.1/docs/languages.md <==
# Languages

| Language | Aliases |
| --- | --- |
| `ABAP` | `abap` |
| `ABNF` | `abnf` |
| `ActionScript` | `as`, `actionscript` |
| `ActionScript 3` | `as3`, `actionscript3` |
| `Ada` | `ada`, `ada95`, `ada2005` |
| `Agda` | `agda` |
| `AL` | `al` |
| `Alloy` | `alloy` |
| `Angular2` | `ng2` |
| `ANTLR` | `antlr` |
| `ApacheConf` | `apacheconf`, `aconf`, `apache` |
| `APL` | `apl` |
| `AppleScript` | `applescript` |
| `ArangoDB AQL` | `aql` |
| `Arduino` | `arduino` |
| `ArmAsm` | `armasm` |
| `ATL` | `atl` |
| `AutoHotkey` | `autohotkey`, `ahk` |
| `AutoIt` | `autoit` |
| `Awk` | `awk`, `gawk`, `mawk`, `nawk` |
| `Ballerina` | `ballerina` |
| `Bash` | `bash`, `sh`, `ksh`, `zsh`, `shell` |
| `Bash Session` | `bash-session`, `console`, `shell-session` |
| `Batchfile` | `bat`, `batch`, `dosbatch`, `winbatch` |
| `Beef` | `beef` |
| `BibTeX` | `bib`, `bibtex` |
| `Bicep` | `bicep` |
| `BlitzBasic` | `blitzbasic`, `b3d`, `bplus` |
| `BNF` | `bnf` |
| `BQN` | `bqn` |
| `Brainfuck` | `brainfuck`, `bf` |
| `C#` | `csharp`, `c#` |
| `C++` | `cpp`, `c++` |
| `C` | `c` |
| `C3` | `c3` |
| `Cap'n Proto` | `capnp` |
| `Cassandra CQL` | `cassandra`, `cql` |
| `Ceylon` | `ceylon` |
| `CFEngine3` | `cfengine3`, `cf3` |
| `cfstatement` | `cfs` |
| `ChaiScript` | `chai`, `chaiscript` |
| `Chapel` | `chapel`, `chpl` |
| `Cheetah` | `cheetah`, `spitfire` |
| `Clojure` | `clojure`, `clj`, `edn` |
| `CMake` | `cmake` |
| `COBOL` | `cobol` |
| `CoffeeScript` | `coffee-script`, `coffeescript`, `coffee` |
| `Common Lisp` | `common-lisp`, `cl`, `lisp` |
| `Coq` | `coq` |
| `Core` | `core` |
| `Crystal` | `cr`, `crystal` |
| `CSS` | `css` |
| `CSV` | `csv` |
| `CUE` | `cue` |
| `Cython` | `cython`, `pyx`, `pyrex` |
| `D` | `d` |
| `Dart` | `dart` |
| `Dax` | `dax` |
| `Desktop file` | `desktop`, `desktop_entry` |
| `Devicetree` | `devicetree`, `dts` |
| `Diff` | `diff`, `udiff` |
| `Django/Jinja` | `django`, `jinja` |
| `dns` | `zone`, `bind` |
| `Docker` | `docker`, `dockerfile`, `containerfile` |
| `DTD` | `dtd` |
| `Dylan` | `dylan` |
| `EBNF` | `ebnf` |
| `Elixir` | `elixir`, `ex`, `exs` |
| `Elm` | `elm` |
| `EmacsLisp` | `emacs`, `elisp`, `emacs-lisp` |
| `Erlang` | `erlang` |
| `Factor` | `factor` |
| `Fennel` | `fennel`, `fnl` |
| `Fish` | `fish`, `fishshell` |
| `Forth` | `forth` |
| `Fortran` | `fortran`, `f90` |
| `FortranFixed` | `fortranfixed` |
| `FSharp` | `fsharp` |
| `GAS` | `gas`, `asm` |
| `GDScript` | `gdscript`, `gd` |
| `GDScript3` | `gdscript3`, `gd3` |
| `Gherkin` | `cucumber`, `Cucumber`, `gherkin`, `Gherkin` |
| `Gleam` | `gleam` |
| `GLSL` | `glsl` |
| `Gnuplot` | `gnuplot` |
| `Go Template` | `go-template` |
| `GraphQL` | `graphql`, `graphqls`, `gql` |
| `Groff` | `groff`, `nroff`, `man` |
| `Groovy` | `groovy` |
| `Handlebars` | `handlebars`, `hbs` |
| `Hare` | `hare` |
| `Haskell` | `haskell`, `hs` |
| `HCL` | `hcl` |
| `Hexdump` | `hexdump` |
| `HLB` | `hlb` |
| `HLSL` | `hlsl` |
| `HolyC` | `holyc` |
| `HTML` | `html` |
| `Hy` | `hylang` |
| `Idris` | `idris`, `idr` |
| `Igor` | `igor`, `igorpro` |
| `INI` | `ini`, `cfg`, `dosini` |
| `Io` | `io` |
| `ISCdhcpd` | `iscdhcpd` |
| `J` | `j` |
| `Janet` | `janet` |
| `Java` | `java` |
| `JavaScript` | `js`, `javascript` |
| `JSON` | `json` |
| `JSONata` | `jsonata` |
| `Jsonnet` | `jsonnet` |
| `Julia` | `julia`, `jl` |
| `Jungle` | `jungle` |
| `Kakoune` | `kak`, `kakoune`, `kakrc`, `kakscript` |
| `Kotlin` | `kotlin` |
| `Lean4` | `lean4`, `lean` |
| `Lighttpd configuration file` | `lighty`, `lighttpd` |
| `LLVM` | `llvm` |
| `lox` | |
| `Lua` | `lua`, `luau` |
| `Makefile` | `make`, `makefile`, `mf`, `bsdmake` |
| `Mako` | `mako` |
| `Mason` | `mason` |
| `Materialize SQL dialect` | `materialize`, `mzsql` |
| `Mathematica` | `mathematica`, `mma`, `nb` |
| `Matlab` | `matlab` |
| `MCFunction` | `mcfunction`, `mcf` |
| `Meson` | `meson`, `meson.build` |
| `Metal` | `metal` |
| `MiniZinc` | `minizinc`, `MZN`, `mzn` |
| `MLIR` | `mlir` |
| `Modelica` | `modelica` |
| `Modula-2` | `modula2`, `m2` |
| `Mojo` | `mojo`, `🔥` |
| `MonkeyC` | `monkeyc` |
| `MoonScript` | `moonscript`, `moon` |
| `MorrowindScript` | `morrowind`, `mwscript` |
| `Myghty` | `myghty` |
| `MySQL` | `mysql`, `mariadb` |
| `NASM` | `nasm` |
| `Natural` | `natural` |
| `NDISASM` | `ndisasm` |
| `Newspeak` | `newspeak` |
| `Nginx configuration file` | `nginx` |
| `Nim` | `nim`, `nimrod` |
| `Nix` | `nixos`, `nix` |
| `NSIS` | `nsis`, `nsi`, `nsh` |
| `Nu` | `nu` |
| `Objective-C` | `objective-c`, `objectivec`, `obj-c`, `objc` |
| `ObjectPascal` | `objectpascal` |
| `OCaml` | `ocaml` |
| `Octave` | `octave` |
| `Odin` | `odin` |
| `OnesEnterprise` | `ones`, `onesenterprise`, `1S`, `1S:Enterprise` |
| `OpenEdge ABL` | `openedge`, `abl`, `progress`, `openedgeabl` |
| `OpenSCAD` | `openscad` |
| `Org Mode` | `org`, `orgmode` |
| `PacmanConf` | `pacmanconf` |
| `Perl` | `perl`, `pl` |
| `PHP` | `php`, `php3`, `php4`, `php5` |
| `Pig` | `pig` |
| `PkgConfig` | `pkgconfig` |
| `PL/pgSQL` | `plpgsql` |
| `plaintext` | `text`, `plain`, `no-highlight` |
| `Plutus Core` | `plutus-core`, `plc` |
| `Pony` | `pony` |
| `PostgreSQL SQL dialect` | `postgresql`, `postgres` |
| `PostScript` | `postscript`, `postscr` |
| `POVRay` | `pov` |
| `PowerQuery` | `powerquery`, `pq` |
| `PowerShell` | `powershell`, `posh`, `ps1`, `psm1`, `psd1`, `pwsh` |
| `Prolog` | `prolog` |
| `Promela` | `promela` |
| `PromQL` | `promql` |
| `properties` | `java-properties` |
| `Protocol Buffer` | `protobuf`, `proto` |
| `PRQL` | `prql` |
| `PSL` | `psl` |
| `Puppet` | `puppet` |
| `Python` | `python`, `py`, `sage`, `python3`, `py3`, `starlark` |
| `Python 2` | `python2`, `py2` |
| `QBasic` | `qbasic`, `basic` |
| `QML` | `qml`, `qbs` |
| `R` | `splus`, `s`, `r` |
| `Racket` | `racket`, `rkt` |
| `Ragel` | `ragel` |
| `react` | `jsx`, `react` |
| `ReasonML` | `reason`, `reasonml` |
| `reg` | `registry` |
| `Rego` | `rego` |
| `Rexx` | `rexx`, `arexx` |
| `RGBDS Assembly` | `rgbasm` |
| `Ring` | `ring` |
| `RPGLE` | `SQLRPGLE`, `RPG IV` |
| `RPMSpec` | `spec` |
| `Ruby` | `rb`, `ruby`, `duby` |
| `Rust` | `rust`, `rs` |
| `SAS` | `sas` |
| `Sass` | `sass` |
| `Scala` | `scala` |
| `Scheme` | `scheme`, `scm` |
| `Scilab` | `scilab` |
| `SCSS` | `scss` |
| `Sed` | `sed`, `gsed`, `ssed` |
| `Sieve` | `sieve` |
| `Smali` | `smali` |
| `Smalltalk` | `smalltalk`, `squeak`, `st` |
| `Smarty` | `smarty` |
| `SNBT` | `snbt` |
| `Snobol` | `snobol` |
| `Solidity` | `sol`, `solidity` |
| `SourcePawn` | `sp` |
| `SPARQL` | `sparql` |
| `SQL` | `sql` |
| `SquidConf` | `squidconf`, `squid.conf`, `squid` |
| `Standard ML` | `sml` |
| `stas` | |
| `Stylus` | `stylus` |
| `Swift` | `swift` |
| `SYSTEMD` | `systemd` |
| `systemverilog` | `systemverilog`, `sv` |
| `TableGen` | `tablegen` |
| `Tal` | `tal`, `uxntal` |
| `TASM` | `tasm` |
| `Tcl` | `tcl` |
| `Tcsh` | `tcsh`, `csh` |
| `Termcap` | `termcap` |
| `Terminfo` | `terminfo` |
| `Terraform` | `terraform`, `tf`, `hcl` |
| `TeX` | `tex`, `latex` |
| `Thrift` | `thrift` |
| `TOML` | `toml` |
| `TradingView` | `tradingview`, `tv` |
| `Transact-SQL` | `tsql`, `t-sql` |
| `Turing` | `turing` |
| `Turtle` | `turtle` |
| `Twig` | `twig` |
| `Protocol Buffer Text Format` | `txtpb` |
| `TypeScript` | `ts`, `tsx`, `typescript` |
| `TypoScript` | `typoscript` |
| `TypoScriptCssData` | `typoscriptcssdata` |
| `TypoScriptHtmlData` | `typoscripthtmldata` |
| `Typst` | `typst` |
| `ucode` | |
| `V` | `v`, `vlang` |
| `V shell` | `vsh`, `vshell` |
| `Vala` | `vala`, `vapi` |
| `VB.net` | `vb.net`, `vbnet` |
| `verilog` | `verilog`, `v` |
| `VHDL` | `vhdl` |
| `VHS` | `vhs`, `tape`, `cassette` |
| `VimL` | `vim` |
| `vue` | `vue`, `vuejs` |
| `WebAssembly Text Format` | `wast`, `wat` |
| `WDTE` | |
| `WebGPU Shading Language` | `wgsl` |
| `WebVTT` | `vtt` |
| `Whiley` | `whiley` |
| `XML` | `xml` |
| `Xorg` | `xorg.conf` |
| `YAML` | `yaml` |
| `YANG` | `yang` |
| `Z80 Assembly` | `z80` |
| `Zed` | `zed` |
| `Zig` | `zig` |
| `Caddyfile` | `caddyfile`, `caddy` |
| `Caddyfile Directives` | `caddyfile-directives`, `caddyfile-d`, `caddy-d` |
| `Gemtext` | `gemtext`, `gmi`, `gmni`, `gemini` |
| `Genshi Text` | `genshitext` |
| `Genshi HTML` | `html+genshi`, `html+kid` |
| `Genshi` | `genshi`, `kid`, `xml+genshi`, `xml+kid` |
| `Go HTML Template` | `go-html-template` |
| `Go Text Template` | `go-text-template` |
| `Go` | `go`, `golang` |
| `Haxe` | `hx`, `haxe`, `hxsl` |
| `HTTP` | `http` |
| `markdown` | `md`, `mkd` |
| `PHTML` | `phtml` |
| `Raku` | `perl6`, `pl6`, `raku` |
| `reStructuredText` | `rst`, `rest`, `restructuredtext` |
| `Svelte` | `svelte` |
